#!/usr/bin/env python

# __author__ = "Eric Allen Youngson"
# __email__ = "eric@successionecological.com"
# __copyright__ = "Copyright 2015, Succession Ecological Services"
# __license__ = "GNU Affero (GPLv3)"

""" This module provides functions for requesting results from the Google
    calendar API """


import sys
sys.path.append('../geepal')

from datetime import datetime, date, timedelta
from pyinvoice.models import InvoiceInfo, ServiceProviderInfo, ClientInfo, Item, Transaction
from pyinvoice.templates import SimpleInvoice

import time
import iso8601
import pandas as pd
import pprint as pp

import get_events as ge

import pytest


def test_add_durations():
    """ """

    pass


def test_hrs_min_sec():
    """ """

    pass


def test_get_cals_durs():
    """ """

    pass


def test_summarize_cals_durs():
    """ """

    pass


def test_get_unique_events():
    """ """

    pass


def test_get_projects():
    """ """

    pass
